@@ -14,7 +14,7 @@
 #include <KIO/MimeTypeFinderJob>
 
 #include <Purpose/AlternativesModel>
-#include <PurposeWidgets/Menu>
+#include <Purpose/Menu>
 
 PurposePlugin::PurposePlugin(QObject *parent)
     : AbstractBrowserPlugin(QStringLiteral("purpose"), 1, parent)
@@ -182,3 +182,5 @@ void PurposePlugin::showShareMenu(const QJsonObject &data, const QString &mimeTy
 
     m_menu->popup(QCursor::pos());
 }
+
+#include "moc_purposeplugin.cpp"
